@@ -13,7 +13,7 @@ use Filter::signatures;
 use feature 'signatures';
 no warnings 'experimental::signatures';
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 =head1 NAME
 
@@ -72,7 +72,7 @@ has output => (
 
 sub _build_body( $self ) {
     if( my $body = $self->body ) {
-        $body =~ s!([\x00-\x1f"'\\])!sprintf '\\x%02x', ord $1!ge;
+        $body =~ s!([\x00-\x1f'\\])!sprintf '\\x%02x', ord $1!ge;
         return sprintf "'%s'", $body
 
     } else {
