@@ -14,7 +14,7 @@ use Filter::signatures;
 use feature 'signatures';
 no warnings 'experimental::signatures';
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 =head1 NAME
 
@@ -40,7 +40,7 @@ HTTP::Request::FromCurl - create a HTTP::Request from a curl command line
     );
     # Send the requests
     for my $r (@requests) {
-        $ua->request( $r )
+        $ua->request( $r->as_request )
     }
 
 =head1 METHODS
@@ -57,8 +57,10 @@ HTTP::Request::FromCurl - create a HTTP::Request from a curl command line
         command => '--agent myscript/1.0 https://example.com',
     );
 
-If the command generates multiple requests, they will be returned in list
-context. In scalar context, only the first request will be returned.
+The constructor returns one or more L<HTTP::Request::CurlParameters> objects
+that encapsulate the parameters. If the command generates multiple requests,
+they will be returned in list context. In scalar context, only the first request
+will be returned.
 
     my $req = HTTP::Request::FromCurl->new(
         command => '--data-binary @/etc/passwd https://example.com',
@@ -100,6 +102,7 @@ our @option_spec = (
     'verbose|v',
     'silent|s',
     #'c|cookie-jar=s',   # ignored
+    'compressed',
     'data|d=s@',
     'data-binary=s@',
     'referrer|e=s',
@@ -280,6 +283,11 @@ sub _build_request( $self, $uri, $options, %build_options ) {
         $headers{ 'User-Agent' } = $options->{ 'agent' };
     };
 
+    if( $options->{ compressed }) {
+        my $compressions = HTTP::Message::decodable();
+        $headers{ 'Accept-Encoding' } = $compressions;
+    };
+
     HTTP::Request::CurlParameters->new({
         method => $method,
         uri    => $uri,
